Class: Payabli::Export::Client
- Inherits:
-
Object
- Object
- Payabli::Export::Client
- Defined in:
- lib/payabli/export/client.rb
Instance Method Summary collapse
-
#export_applications(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_batch_details(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_batch_details_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_batches(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_batches_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_batches_out(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_batches_out_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_bills(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_bills_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_chargebacks(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_chargebacks_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_customers(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_customers_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_invoices(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_invoices_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_organizations(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_payout(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_payout_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_paypoints(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_settlements(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_settlements_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_subscriptions(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_subscriptions_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_transactions(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_transactions_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_transfer_details(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_transfers(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_vendors(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
-
#export_vendors_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated.
- #initialize(client:) ⇒ void constructor
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/payabli/export/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#export_applications(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List all apps for org](/developers/api-reference/boarding/get-list-of-applications-for-an-organization) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of boarding applications for an organization. Use filters to limit results.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/payabli/export/client.rb', line 36 def export_applications(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/boarding/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_batch_details(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List batch details](/developers/api-reference/query/get-list-of-batchdetails-for-an-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export batch details for a paypoint. Use filters to limit results.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/payabli/export/client.rb', line 88 def export_batch_details(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/batchDetails/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_batch_details_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List batch details for org](/developers/api-reference/query/get-list-of-batchdetails-for-an-organization) with the ‘exportFormat` query parameter instead. </Warning>
Export batch details for an organization. Use filters to limit results.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/payabli/export/client.rb', line 140 def export_batch_details_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/batchDetails/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_batches(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List batches for paypoint](/developers/api-reference/query/get-list-of-batches-for-an-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of batches for an entrypoint. Use filters to limit results.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/payabli/export/client.rb', line 192 def export_batches(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/batches/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_batches_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List batches for org](/developers/api-reference/query/get-list-of-batches-for-an-organization) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of batches for an organization. Use filters to limit results.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/payabli/export/client.rb', line 244 def export_batches_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/batches/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_batches_out(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List payout batches for paypoint](/developers/api-reference/query/get-list-of-moneyout-batches-for-an-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of money out batches for a paypoint. Use filters to limit results.
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/payabli/export/client.rb', line 296 def export_batches_out(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/batchesOut/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_batches_out_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List payout batches for org](/developers/api-reference/query/get-list-of-moneyout-batches-for-an-org) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of money out batches for an organization. Use filters to limit results.
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/payabli/export/client.rb', line 348 def export_batches_out_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/batchesOut/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_bills(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List bills by paypoint](/developers/api-reference/bill/get-list-of-bills-for-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of bills for an entrypoint. Use filters to limit results.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/payabli/export/client.rb', line 400 def export_bills(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/bills/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_bills_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List bills by organization](/developers/api-reference/bill/get-list-of-bills-for-organization) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of bills for an organization. Use filters to limit results.
452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/payabli/export/client.rb', line 452 def export_bills_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/bills/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_chargebacks(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List disputes by paypoint](/developers/api-reference/chargebacks/get-list-of-chargebacks-and-returned-transactions-for-an-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of chargebacks and ACH returns for an entrypoint. Use filters to limit results.
504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 |
# File 'lib/payabli/export/client.rb', line 504 def export_chargebacks(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/chargebacks/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_chargebacks_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List disputes by organization](/developers/api-reference/chargebacks/get-list-of-chargebacks-and-returned-transactions-for-an-org) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of chargebacks and ACH returns for an organization. Use filters to limit results.
556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/payabli/export/client.rb', line 556 def export_chargebacks_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/chargebacks/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_customers(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List customers by paypoint](/developers/api-reference/customer/get-list-of-customers-for-an-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of customers for an entrypoint. Use filters to limit results.
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 |
# File 'lib/payabli/export/client.rb', line 608 def export_customers(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/customers/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_customers_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List customers by organization](/developers/api-reference/customer/get-list-of-customers-for-an-organization) with the ‘exportFormat` query parameter instead. </Warning>
Exports a list of customers for an organization. Use filters to limit results.
660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 |
# File 'lib/payabli/export/client.rb', line 660 def export_customers_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/customers/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_invoices(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List invoices by paypoint](/developers/api-reference/invoice/get-list-of-invoices-for-an-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export list of invoices for an entrypoint. Use filters to limit results.
712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 |
# File 'lib/payabli/export/client.rb', line 712 def export_invoices(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/invoices/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_invoices_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List invoices by organization](/developers/api-reference/invoice/get-list-of-invoices-for-an-organization) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of invoices for an organization. Use filters to limit results.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/payabli/export/client.rb', line 764 def export_invoices_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/invoices/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_organizations(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List suborganizations by organization](/developers/api-reference/organization/get-list-of-organizations-for-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of child organizations (suborganizations) for a parent organization.
816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 |
# File 'lib/payabli/export/client.rb', line 816 def export_organizations(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/organizations/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_payout(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List payouts by paypoint](/developers/api-reference/query/get-list-of-payouts-for-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of payouts and their statuses for an entrypoint. Use filters to limit results.
868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 |
# File 'lib/payabli/export/client.rb', line 868 def export_payout(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/payouts/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_payout_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List payouts by org](/developers/api-reference/query/get-list-of-payouts-for-organization) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of payouts and their details for an organization. Use filters to limit results.
920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 |
# File 'lib/payabli/export/client.rb', line 920 def export_payout_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/payouts/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_paypoints(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List paypoints by organization](/developers/api-reference/paypoint/get-list-of-paypoints-for-an-organization) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of paypoints in an organization. Use filters to limit results.
972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 |
# File 'lib/payabli/export/client.rb', line 972 def export_paypoints(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/paypoints/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_settlements(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List settled transactions for paypoint](/developers/api-reference/query/get-list-of-settled-transactions-for-an-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of settled transactions for an entrypoint. Use filters to limit results.
1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 |
# File 'lib/payabli/export/client.rb', line 1024 def export_settlements(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/settlements/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_settlements_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List settled transactions for org](/developers/api-reference/query/get-list-of-settled-transactions-for-an-org) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of settled transactions for an organization. Use filters to limit results.
1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 |
# File 'lib/payabli/export/client.rb', line 1076 def export_settlements_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/settlements/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_subscriptions(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List subscriptions by paypoint](/developers/api-reference/subscription/get-list-of-subscriptions-for-an-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of subscriptions for an entrypoint. Use filters to limit results.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 |
# File 'lib/payabli/export/client.rb', line 1128 def export_subscriptions(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/subscriptions/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_subscriptions_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List subscriptions by organization](/developers/api-reference/subscription/get-list-of-subscriptions-for-an-org) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of subscriptions for an organization. Use filters to limit results.
1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 |
# File 'lib/payabli/export/client.rb', line 1180 def export_subscriptions_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/subscriptions/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_transactions(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List transactions for paypoint](/developers/api-reference/query/get-list-of-transactions-for-an-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of transactions for an entrypoint in a file in XLSX or CSV format. Use filters to limit results. If you don’t specify a date range in the request, the last two months of data are returned.
1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/payabli/export/client.rb', line 1233 def export_transactions(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/transactions/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_transactions_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List transactions for org](/developers/api-reference/query/get-list-of-transactions-for-an-organization) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of transactions for an org in a file in XLSX or CSV format. Use filters to limit results. If you don’t specify a date range in the request, the last two months of data are returned.
1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/payabli/export/client.rb', line 1286 def export_transactions_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/transactions/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_transfer_details(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [Get transfer details](/developers/api-reference/query/get-list-of-transfer-details) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of transfer details for an entrypoint. Use filters to limit results.
1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/payabli/export/client.rb', line 1340 def export_transfer_details(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) query_params["sortBy"] = params[:sort_by] if params.key?(:sort_by) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/transferDetails/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}/#{URI.encode_uri_component(params[:transfer_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_transfers(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List transfers](/developers/api-reference/query/get-list-of-transfers) with the ‘exportFormat` query parameter instead. </Warning>
Get a list of transfers for an entrypoint. Use filters to limit results.
1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 |
# File 'lib/payabli/export/client.rb', line 1393 def export_transfers(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) query_params["sortBy"] = params[:sort_by] if params.key?(:sort_by) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/transfers/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_vendors(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List vendors by paypoint](/developers/api-reference/vendor/get-list-of-vendors-for-entrypoint) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of vendors for an entrypoint. Use filters to limit results.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 |
# File 'lib/payabli/export/client.rb', line 1446 def export_vendors(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/vendors/#{URI.encode_uri_component(params[:format].to_s)}/#{URI.encode_uri_component(params[:entry].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#export_vendors_org(request_options: {}, **params) ⇒ Hash[String, Object]
<Warning> This endpoint is deprecated. To export this data, use [List vendors by organization](/developers/api-reference/vendor/get-list-of-vendors-for-organization) with the ‘exportFormat` query parameter instead. </Warning>
Export a list of vendors for an organization. Use filters to limit results.
1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 |
# File 'lib/payabli/export/client.rb', line 1498 def export_vendors_org(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["columnsExport"] = params[:columns_export] if params.key?(:columns_export) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) query_params["parameters"] = params[:parameters] if params.key?(:parameters) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "Export/vendors/#{URI.encode_uri_component(params[:format].to_s)}/org/#{URI.encode_uri_component(params[:org_id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::File.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |