Class: Payabli::Types::BillOutDataVendor

Inherits:
Internal::Types::Model show all
Defined in:
lib/payabli/types/bill_out_data_vendor.rb

Overview

The vendor associated with the bill. Although you can create a vendor in a create bill request, Payabli recommends creating a vendor separately and passing a valid ‘vendorNumber` here. At minimum, the `vendorNumber` is required.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Payabli::Internal::Types::Model