Class: Payabli::Types::GooglePayMetadata
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Payabli::Types::GooglePayMetadata
- Defined in:
- lib/payabli/types/google_pay_metadata.rb
Overview
This metadata appears only when the domain verification check fails. It gives more information about why the check failed.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Payabli::Internal::Types::Model