Class: Payabli::PaymentMethodDomain::Client
- Inherits:
-
Object
- Object
- Payabli::PaymentMethodDomain::Client
- Defined in:
- lib/payabli/payment_method_domain/client.rb
Instance Method Summary collapse
-
#add_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::AddPaymentMethodDomainApiResponse
Add a payment method domain to an organization or paypoint.
-
#cascade_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::PaymentMethodDomainGeneralResponse
Cascades a payment method domain to all child entities.
-
#delete_payment_method_domain(request_options: {}, **params) ⇒ Payabli::PaymentMethodDomain::Types::DeletePaymentMethodDomainResponse
Delete a payment method domain.
-
#get_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::PaymentMethodDomainApiResponse
Get the details for a payment method domain.
- #initialize(client:) ⇒ void constructor
-
#list_payment_method_domains(request_options: {}, **params) ⇒ Payabli::PaymentMethodDomain::Types::ListPaymentMethodDomainsResponse
Get a list of payment method domains that belong to a PSP, organization, or paypoint.
-
#update_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::PaymentMethodDomainGeneralResponse
Update a payment method domain’s configuration values.
-
#verify_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::PaymentMethodDomainGeneralResponse
Verify a new payment method domain.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/payabli/payment_method_domain/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#add_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::AddPaymentMethodDomainApiResponse
Add a payment method domain to an organization or paypoint.
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/payabli/payment_method_domain/client.rb', line 24 def add_payment_method_domain(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "PaymentMethodDomain", body: Payabli::PaymentMethodDomain::Types::AddPaymentMethodDomainRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::AddPaymentMethodDomainApiResponse.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#cascade_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::PaymentMethodDomainGeneralResponse
Cascades a payment method domain to all child entities. All paypoints and suborganization under this parent will inherit this domain and its settings.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/payabli/payment_method_domain/client.rb', line 60 def cascade_payment_method_domain(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "PaymentMethodDomain/#{URI.encode_uri_component(params[:domain_id].to_s)}/cascade", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::PaymentMethodDomainGeneralResponse.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete_payment_method_domain(request_options: {}, **params) ⇒ Payabli::PaymentMethodDomain::Types::DeletePaymentMethodDomainResponse
Delete a payment method domain. You can’t delete an inherited domain, you must delete a domain at the organization level.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/payabli/payment_method_domain/client.rb', line 95 def delete_payment_method_domain(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "PaymentMethodDomain/#{URI.encode_uri_component(params[:domain_id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::PaymentMethodDomain::Types::DeletePaymentMethodDomainResponse.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::PaymentMethodDomainApiResponse
Get the details for a payment method domain.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/payabli/payment_method_domain/client.rb', line 129 def get_payment_method_domain(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "PaymentMethodDomain/#{URI.encode_uri_component(params[:domain_id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::PaymentMethodDomainApiResponse.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list_payment_method_domains(request_options: {}, **params) ⇒ Payabli::PaymentMethodDomain::Types::ListPaymentMethodDomainsResponse
Get a list of payment method domains that belong to a PSP, organization, or paypoint.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/payabli/payment_method_domain/client.rb', line 166 def list_payment_method_domains(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[entity_id entity_type from_record limit_record] query_params = {} query_params["entityId"] = params[:entity_id] if params.key?(:entity_id) query_params["entityType"] = params[:entity_type] if params.key?(:entity_type) query_params["fromRecord"] = params[:from_record] if params.key?(:from_record) query_params["limitRecord"] = params[:limit_record] if params.key?(:limit_record) params.except(*query_param_names) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "PaymentMethodDomain/list", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::PaymentMethodDomain::Types::ListPaymentMethodDomainsResponse.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::PaymentMethodDomainGeneralResponse
Update a payment method domain’s configuration values.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/payabli/payment_method_domain/client.rb', line 209 def update_payment_method_domain(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) request_data = Payabli::PaymentMethodDomain::Types::UpdatePaymentMethodDomainRequest.new(params).to_h non_body_param_names = ["domainId"] body = request_data.except(*non_body_param_names) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "PaymentMethodDomain/#{URI.encode_uri_component(params[:domain_id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::PaymentMethodDomainGeneralResponse.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#verify_payment_method_domain(request_options: {}, **params) ⇒ Payabli::Types::PaymentMethodDomainGeneralResponse
Verify a new payment method domain. If verification is successful, Apple Pay is automatically activated for the domain.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/payabli/payment_method_domain/client.rb', line 249 def verify_payment_method_domain(request_options: {}, **params) params = Payabli::Internal::Types::Utils.normalize_keys(params) request = Payabli::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "PaymentMethodDomain/#{URI.encode_uri_component(params[:domain_id].to_s)}/verify", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Payabli::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Payabli::Types::PaymentMethodDomainGeneralResponse.load(response.body) else error_class = Payabli::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |