Class: Payabli::Types::BillingProfileQueryResponse
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Payabli::Types::BillingProfileQueryResponse
- Defined in:
- lib/payabli/types/billing_profile_query_response.rb
Overview
A page of billing profiles that belong to an organization, returned by the List profiles endpoint. This is the data behind the Profile Library table in the Payabli Portal.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Payabli::Internal::Types::Model