Class: Payabli::V2MoneyInTypes::Types::V2DeclinedTransactionResponseWrapper
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Payabli::V2MoneyInTypes::Types::V2DeclinedTransactionResponseWrapper
- Defined in:
- lib/payabli/v_2_money_in_types/types/v_2_declined_transaction_response_wrapper.rb
Overview
Response wrapper for declined v2 Money In transaction endpoints (HTTP 402). Returned when a transaction is declined by the card network or issuer. All decline responses use this format with unified response codes starting with ‘D’. The ‘data` field contains transaction details.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Payabli::Internal::Types::Model